pub enum Flow {
Skip,
Consumed,
Event(UiEvent),
}Expand description
Result of routing an input event through a component.
Variants
Skip
The component did not consume the event.
Consumed
The component consumed the event without emitting an application event.
Event(UiEvent)
The component consumed the event and emitted an application event.