pub enum NotificationAction {
Focus,
Report,
FocusReport,
None,
}Expand description
Terminal actions advertised by a structured notification.
Variants
Focus
Ask the terminal to focus the originating window when activated.
Report
Ask the terminal to report activation to the application.
FocusReport
Focus the window and report activation.
None
Explicitly disable the default focus action.