notify

Function notify 

pub fn notify(
    out: &mut impl Write,
    caps: &TerminalCaps,
    notification: &Notification,
) -> Result<()>
Delivers a notification through the protocol selected by caps.

Delivery commands are detached and best-effort. Only terminal output errors are returned to the caller.