Light

Enum Light 

pub enum Light {
    Point {
        position: Vec3,
        color: Vec3,
        intensity: f32,
    },
    Directional {
        direction: Vec3,
        color: Vec3,
        intensity: f32,
    },
}
An analytic light evaluated without sampling noise.

Variants



Point

An isotropic point source. intensity is radiant intensity and therefore falls off with the inverse square of distance.

Fields

position: Vec3

World-space source position.

color: Vec3

Unit-scale linear RGB source color.

intensity: f32

Non-negative radiant intensity multiplier.



Directional

A source at infinity. direction is the direction its rays travel.

Fields

direction: Vec3

Unit direction from the light toward the scene.

color: Vec3

Unit-scale linear RGB source color.

intensity: f32

Non-negative incident irradiance multiplier.

Implementations

Source

impl Light

pub const fn point(position: Vec3, color: Vec3, intensity: f32) -> Self

Creates an inverse-square point light in linear color space.

pub fn directional(direction: Vec3, color: Vec3, intensity: f32) -> Self

Creates a directional light whose rays travel along direction.