pub struct GeometryHit {
pub t: f32,
pub point: Vec3,
pub geometric_normal: Vec3,
pub shading_normal: Vec3,
pub uv: (f32, f32),
}Expand description
Geometry-local intersection data before a material and face orientation are applied.
Fields
t: f32Ray parameter at the intersection.
point: Vec3World-space intersection point.
geometric_normal: Vec3Outward geometric surface normal.
shading_normal: Vec3Outward smooth or perturbed normal used for shading.
uv: (f32, f32)Surface coordinates in the unit square where the primitive defines them.