UiHandle

Struct UiHandle 

pub struct UiHandle { /* private fields */ }
Cloneable remote for mutating the Ui from any thread or task.

Sends are non-blocking; after the App is gone they are no-ops.

Implementations

Source

impl UiHandle

pub fn update(&self, update: impl FnOnce(&mut Ui) + Send + 'static)

Queues a UI mutation to run between rendered frames.

Examples found in repository?
examples/tml.rs (line 73)
42async fn main() -> io::Result<()> {
43	let path = std::env::args()
44		.nth(1)
45		.unwrap_or_else(|| "example.tml".into());
46	let source = std::fs::read_to_string(&path)?;
47
48	let mut ctx = None;
49	let mut app = AppOptions::new()
50		.quit([Key::Ctrl('c'), Key::Char('q'), Key::Esc])
51		.start(|env| {
52			let ui = build(&source, env.viewport.width, &env.ctx);
53			ctx = Some(env.ctx);
54			ui
55		})
56		.await?;
57	let ctx = ctx.expect("start ran the builder");
58
59	let handle = app.handle();
60	tokio::spawn(async move {
61		let mut seen = modified(path.as_ref());
62		loop {
63			tokio::time::sleep(Duration::from_millis(150)).await;
64			let stamp = modified(path.as_ref());
65			if stamp == seen {
66				continue;
67			}
68			seen = stamp;
69			let Ok(source) = std::fs::read_to_string(&path) else {
70				continue;
71			};
72			let ctx = ctx.clone();
73			handle.update(move |ui| *ui = build(&source, ui.frame().size().width, &ctx));
74		}
75	});
76
77	while app.next().await?.is_some() {}
78	Ok(())
79}
pub fn set_text(&self, id: impl Into<Str>, text: impl Into<Str>)

Queues replacement text for the component named by id.

pub fn invalidate(&self, id: impl Into<Str>)

Queues invalidation of the component named by id.

pub fn shutdown(&self)

Requests shutdown of the application host.