Module ttyid

Module ttyid 

Stable controlling-terminal identity helpers. Stable identifiers for the terminal attached to standard input.

Constants

UNKNOWN_TERMINAL_ID
Stable identifier used when neither a TTY nor a terminal environment variable is available.

Functions

terminal_id
Resolve a stable identifier for the terminal attached to standard input.
terminal_id_with
Resolve a terminal identifier from an injected TTY path and environment.