LoopWatchdog

Struct LoopWatchdog 

pub struct LoopWatchdog { /* private fields */ }
Background render-loop watchdog.

Call Self::tick after each successful render-loop iteration and update Self::set_phase when entering a diagnostic phase. A background probe invokes the supplied callback once per continuous stall longer than 250 ms. Gaps longer than 60 seconds are ignored as probable system sleep.

Implementations

Source

impl LoopWatchdog

pub fn new(report: impl Fn(Duration, &str) + Send + 'static) -> Self

Start a watchdog and send detected stalls to report.

pub fn tick(&self)

Record progress by the render loop.

pub fn set_phase(&self, phase: impl Into<Str>)

Set the phase label attached to a subsequently detected stall.

pub fn stop(&mut self)

Stop the background probe and wait for it to exit.