pub struct Aabb {
pub min: Vec3,
pub max: Vec3,
}Expand description
An axis-aligned bounding box represented by inclusive minimum and maximum corners.
Fields
min: Vec3Smallest coordinate on each axis.
max: Vec3Largest coordinate on each axis.
Implementations
Sourceimpl Aabb
impl Aabb
Sourcepub const fn new(min: Vec3, max: Vec3) -> Self
pub const fn new(min: Vec3, max: Vec3) -> Self
Creates a bounding box from already ordered corners.
Sourcepub const fn from_points(a: Vec3, b: Vec3) -> Self
pub const fn from_points(a: Vec3, b: Vec3) -> Self
Creates the smallest box containing both points.
Sourcepub fn is_valid(self) -> bool
pub fn is_valid(self) -> bool
Returns whether every coordinate is finite and the corners are ordered.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the smallest box containing both input boxes.
Sourcepub fn centroid(self) -> Vec3
pub fn centroid(self) -> Vec3
Returns the midpoint of the box without overflowing finite coordinates.