Stable controlling-terminal identity helpers. Stable identifiers for the terminal attached to standard input.
Constants
- UNKNOWN_
TERMINAL_ ID - Stable identifier used when neither a TTY nor a terminal environment variable is available.
Functions
- terminal_
id - Resolve a stable identifier for the terminal attached to standard input.
- terminal_
id_ with - Resolve a terminal identifier from an injected TTY path and environment.